#' GDPuc package
#'
#' @description
#' `r lifecycle::badge('stable')`
#'
#' Convert GDP time series data from one unit to another. All common GDP units are included, i.e. current and constant
#'  local currency units, US$ via market exchange rates and international dollars via purchasing power parities.
#'
#' @name GDPuc-package
#' @aliases GDPuc-package GDPuc
#' @importFrom magrittr %>%
#' @importFrom rlang !! := .data
#' @keywords internal
"_PACKAGE"
